@@ -89,7 +89,7 @@ class Interface:
         description (str): a description for the interface; if provided, appears above the input and output components.
         article (str): an expanded article explaining the interface; if provided, appears below the input and output components. Accepts Markdown and HTML content.
         thumbnail (str): path to image or src to use as display picture for models listed in gradio.app/hub
-        theme (str): Theme to use - one of "default", "compact" or "huggingface".
+        theme (str): Theme to use - one of "default", "compact", "huggingface", or "darkhuggingface".
         css (str): custom css or path to custom css file to use with interface.
         server_port (int): will start gradio app on this port (if available) 
         server_name (str): to make app accessible on local network set to "0.0.0.0".
@@ -143,7 +143,10 @@ class Interface:
             article = markdown2.markdown(article, extras=["fenced-code-blocks"])
         self.article = article
         self.thumbnail = thumbnail
-        self.theme = theme if theme is not None else os.getenv("GRADIO_THEME", "default")
+        theme = theme if theme is not None else os.getenv("GRADIO_THEME", "default")
+        if theme not in ("default", "compact", "huggingface", "darkhuggingface"):
+            raise ValueError("Invalid theme name.")
+        self.theme = theme
         self.height = height
         self.width = width
         if css is not None and os.path.exists(css):
