@@ -36,6 +36,7 @@ class Textbox(OutputComponent):
     '''
     Component creates a textbox to render output text or number.
     Output type: Union[str, float, int]
+    Demos: hello_world.py, sentence_builder.py
     '''
 
     def __init__(self, type="auto", label=None):
@@ -73,6 +74,7 @@ class Label(OutputComponent):
     '''
     Component outputs a classification label, along with confidence scores of top categories if provided. Confidence scores are represented as a dictionary mapping labels to scores between 0 and 1.
     Output type: Union[Dict[str, float], str, int, float]
+    Demos: image_classifier.py, main_note.py, titanic_survival.py
     '''
 
     CONFIDENCES_KEY = "confidences"
@@ -138,6 +140,7 @@ class Image(OutputComponent):
     '''
     Component displays an output image. 
     Output type: Union[numpy.array, PIL.Image, str, matplotlib.pyplot, Tuple[Union[numpy.array, PIL.Image, str], List[Tuple[str, float, float, float, float]]]]
+    Demos: image_mod.py, webcam.py
     '''
 
     def __init__(self, type="auto", labeled_segments=False, plot=False, label=None):
@@ -206,6 +209,7 @@ class Video(OutputComponent):
     '''
     Used for video output.     
     Output type: filepath
+    Demos: video_flip.py
     '''
 
     def __init__(self, label=None):
@@ -235,6 +239,7 @@ class KeyValues(OutputComponent):
     '''
     Component displays a table representing values for multiple fields. 
     Output type: Union[Dict, List[Tuple[str, Union[str, int, float]]]]
+    Demos: text_analysis.py
     '''
 
     def __init__(self, label=None):
@@ -271,6 +276,7 @@ class HighlightedText(OutputComponent):
     Component creates text that contains spans that are highlighted by category or numerical value.
     Output is represent as a list of Tuple pairs, where the first element represents the span of text represented by the tuple, and the second element represents the category or value of the text.
     Output type: List[Tuple[str, Union[float, str]]]
+    Demos: diff_texts.py, text_analysis.py
     '''
 
     def __init__(self, color_map=None, label=None):
@@ -308,6 +314,7 @@ class Audio(OutputComponent):
     '''
     Creates an audio player that plays the output audio.
     Output type: Union[Tuple[int, numpy.array], str]
+    Demos: generate_tone.py, reverse_audio.py
     '''
 
     def __init__(self, type="auto", label=None):
@@ -351,6 +358,7 @@ class JSON(OutputComponent):
     '''
     Used for JSON output. Expects a JSON string or a Python object that is JSON serializable. 
     Output type: Union[str, Any]
+    Demos: zip_to_json.py
     '''
 
     def __init__(self, label=None):
@@ -384,6 +392,7 @@ class HTML(OutputComponent):
     '''
     Used for HTML output. Expects an HTML valid string. 
     Output type: str
+    Demos: text_analysis.py
     '''
 
     def __init__(self, label=None):
@@ -405,6 +414,7 @@ class File(OutputComponent):
     '''
     Used for file output.     
     Output type: Union[file-like, str]
+    Demos: zip_two_files.py
     '''
 
     def __init__(self, label=None):
@@ -439,6 +449,7 @@ class Dataframe(OutputComponent):
     """
     Component displays 2D output through a spreadsheet interface.
     Output type: Union[pandas.DataFrame, numpy.array, List[Union[str, float]], List[List[Union[str, float]]]]
+    Demos: filter_records.py, matrix_transpose.py, fraud_detector.py
     """
 
     def __init__(self, headers=None, max_rows=20, max_cols=None, overflow_row_behaviour="paginate", type="auto", label=None):
@@ -512,6 +523,7 @@ class Carousel(OutputComponent):
     """
     Component displays a set of output components that can be scrolled through.
     Output type: List[List[Any]]
+    Demos: disease_report.py
     """
 
     def __init__(self, components, label=None):
@@ -566,3 +578,54 @@ def get_output_instance(iface):
             "Output interface must be of type `str` or "
             "`OutputComponent`"
         )
+
+class Timeseries(OutputComponent):
+    """
+    Component accepts pandas.DataFrame.
+    Output type: pandas.DataFrame
+    Demos: fraud_detector.py
+    """
+
+    def __init__(self, x=None, y=None, label=None):
+        """
+        Parameters:
+        x (str): Column name of x (time) series. None if csv has no headers, in which case first column is x series.
+        y (Union[str, List[str]]): Column name of y series, or list of column names if multiple series. None if csv has no headers, in which case every column after first is a y series.
+        label (str): component name in interface.
+        """
+        self.x = x
+        if isinstance(y, str):
+            y = [y]
+        self.y = y
+        super().__init__(label)
+
+    def get_template_context(self):
+        return {
+            "x": self.x,
+            "y": self.y,
+            **super().get_template_context()
+        }
+
+    @classmethod
+    def get_shortcut_implementations(cls):
+        return {
+            "timeseries": {},
+        }
+
+    def postprocess(self, y):
+        return {
+            "headers": y.columns.values.tolist(),
+            "data": y.values.tolist()
+
+        }
+
+
+    def save_flagged(self, dir, label, data, encryption_key):
+        """
+        Returns: (List[List[Union[str, float]]]) 2D array
+        """
+        return json.dumps(data)
+
+    def restore_flagged(self, data):
+        return json.loads(data)
+
